==> org.opennms.features.remote-poller-gwt-20.0.0-20170412.041126-144-sources.jar: org/opennms/features/poller/remote/gwt/CacheFilter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.poller.remote.gwt;

import java.io.IOException;
import java.util.Date;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * <p>CacheFilter class.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public class CacheFilter implements Filter {
	private static final long ONE_DAY = 1000 * 60 * 60 * 24;

	/** {@inheritDoc} */
        @Override
	public void init(final FilterConfig config) throws ServletException {
	}

	/**
	 * <p>destroy</p>
	 */
        @Override
	public void destroy() {
	}

	/** {@inheritDoc} */
        @Override
	public void doFilter(final ServletRequest req, final ServletResponse resp, final FilterChain chain) throws IOException, ServletException {
		if (!(req instanceof HttpServletRequest)) {
			chain.doFilter(req, resp);
			return;
		}
		if (!(resp instanceof HttpServletResponse)) {
			chain.doFilter(req, resp);
			return;
		}
		final HttpServletRequest request = (HttpServletRequest)req;
		final HttpServletResponse response = (HttpServletResponse)resp;
		
		final String requestURI = request.getRequestURI();
		if (requestURI.endsWith(".png") || requestURI.endsWith(".css")) {
			final long today = new Date().getTime();
			response.setDateHeader("Expires", today + ONE_DAY);
			chain.doFilter(request, response);
		} else {
			chain.doFilter(req, resp);
		}
	}

}

==> org.opennms.features.remote-poller-gwt-21.1.0-20181216.151648-28-sources.jar: org/opennms/features/poller/remote/gwt/CacheFilter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.poller.remote.gwt;

import java.io.IOException;
import java.util.Date;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * <p>CacheFilter class.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public class CacheFilter implements Filter {
	private static final long ONE_DAY = 1000L * 60L * 60L * 24L;

	/** {@inheritDoc} */
        @Override
	public void init(final FilterConfig config) throws ServletException {
	}

	/**
	 * <p>destroy</p>
	 */
        @Override
	public void destroy() {
	}

	/** {@inheritDoc} */
        @Override
	public void doFilter(final ServletRequest req, final ServletResponse resp, final FilterChain chain) throws IOException, ServletException {
		if (!(req instanceof HttpServletRequest)) {
			chain.doFilter(req, resp);
			return;
		}
		if (!(resp instanceof HttpServletResponse)) {
			chain.doFilter(req, resp);
			return;
		}
		final HttpServletRequest request = (HttpServletRequest)req;
		final HttpServletResponse response = (HttpServletResponse)resp;
		
		final String requestURI = request.getRequestURI();
		if (requestURI.endsWith(".png") || requestURI.endsWith(".css")) {
			final long today = new Date().getTime();
			response.setDateHeader("Expires", today + ONE_DAY);
			chain.doFilter(request, response);
		} else {
			chain.doFilter(req, resp);
		}
	}

}
